# Loggylog gRPC related auto-generated code

Code generated using proto compiler.


## Installation

```sh
pip install loggylog-grpc
```

## Usage

```python
from logs_proto import logs_pb2_grpc, logs_pb2

# ... your code here ...
```
